@@ -1,5 +1,5 @@
 -----------------------------------------------------------------------------
--- $Id: 9517823742379b59a753184cda7823de6989b643 $                 	   --
+-- $Id: 9bdaf71f34013de79504b9bf6e090c8cf0e38979 $                 	   --
 --                                                                         --
 --  schema.sql                       rlm_sql - FreeRADIUS SQLite Module    --
 --                                                                         --
@@ -10,14 +10,14 @@
 --
 -- Table structure for table 'radacct'
 --
-CREATE TABLE radacct (
+CREATE TABLE IF NOT EXISTS radacct (
 	radacctid INTEGER PRIMARY KEY AUTOINCREMENT,
 	acctsessionid varchar(64) NOT NULL default '',
 	acctuniqueid varchar(32) NOT NULL default '',
 	username varchar(64) NOT NULL default '',
 	realm varchar(64) default '',
 	nasipaddress varchar(15) NOT NULL default '',
-	nasportid varchar(15) default NULL,
+	nasportid varchar(32) default NULL,
 	nasporttype varchar(32) default NULL,
 	acctstarttime datetime NULL default NULL,
 	acctupdatetime datetime NULL default NULL,
@@ -25,8 +25,8 @@ CREATE TABLE radacct (
 	acctinterval int(12) default NULL,
 	acctsessiontime int(12) default NULL,
 	acctauthentic varchar(32) default NULL,
-	connectinfo_start varchar(50) default NULL,
-	connectinfo_stop varchar(50) default NULL,
+	connectinfo_start varchar(128) default NULL,
+	connectinfo_stop varchar(128) default NULL,
 	acctinputoctets bigint(20) default NULL,
 	acctoutputoctets bigint(20) default NULL,
 	calledstationid varchar(50) NOT NULL default '',
@@ -38,9 +38,19 @@ CREATE TABLE radacct (
 	framedipv6address varchar(45) NOT NULL default '',
 	framedipv6prefix varchar(45) NOT NULL default '',
 	framedinterfaceid varchar(44) NOT NULL default '',
-	delegatedipv6prefix varchar(45) NOT NULL default ''
+	delegatedipv6prefix varchar(45) NOT NULL default '',
+	class varchar(64) default NULL
 );
 
+--
+--  You might not need all of these indexes.  It should be safe to
+--  delete indexes you do not use.  For example, if you're not using
+--  IPv6, you can delete the indexes on IPv6 attributes.
+--
+--  You MUST however leave the indexes needed by the server, which
+--  include username, acctstoptime, nasipaddress, acctstarttime, and
+--  acctuniqueid.
+--
 CREATE UNIQUE INDEX acctuniqueid ON radacct(acctuniqueid);
 CREATE INDEX username ON radacct(username);
 CREATE INDEX framedipaddress ON radacct (framedipaddress);
@@ -54,11 +64,12 @@ CREATE INDEX acctstarttime ON radacct(acctstarttime);
 CREATE INDEX acctinterval ON radacct(acctinterval);
 CREATE INDEX acctstoptime ON radacct(acctstoptime);
 CREATE INDEX nasipaddress ON radacct(nasipaddress);
+CREATE INDEX class ON radacct(class);
 
 --
 -- Table structure for table 'radcheck'
 --
-CREATE TABLE radcheck (
+CREATE TABLE IF NOT EXISTS radcheck (
 	id INTEGER PRIMARY KEY AUTOINCREMENT,
 	username varchar(64) NOT NULL default '',
 	attribute varchar(64)  NOT NULL default '',
@@ -70,7 +81,7 @@ CREATE INDEX check_username ON radcheck(username);
 --
 -- Table structure for table 'radgroupcheck'
 --
-CREATE TABLE radgroupcheck (
+CREATE TABLE IF NOT EXISTS radgroupcheck (
 	id INTEGER PRIMARY KEY AUTOINCREMENT,
 	groupname varchar(64) NOT NULL default '',
 	attribute varchar(64)  NOT NULL default '',
@@ -82,7 +93,7 @@ CREATE INDEX check_groupname ON radgroupcheck(groupname);
 --
 -- Table structure for table 'radgroupreply'
 --
-CREATE TABLE radgroupreply (
+CREATE TABLE IF NOT EXISTS radgroupreply (
 	id INTEGER PRIMARY KEY AUTOINCREMENT,
 	groupname varchar(64) NOT NULL default '',
 	attribute varchar(64)  NOT NULL default '',
@@ -94,7 +105,7 @@ CREATE INDEX reply_groupname ON radgroupreply(groupname);
 --
 -- Table structure for table 'radreply'
 --
-CREATE TABLE radreply (
+CREATE TABLE IF NOT EXISTS radreply (
 	id INTEGER PRIMARY KEY AUTOINCREMENT,
 	username varchar(64) NOT NULL default '',
 	attribute varchar(64) NOT NULL default '',
@@ -106,7 +117,7 @@ CREATE INDEX reply_username ON radreply(username);
 --
 -- Table structure for table 'radusergroup'
 --
-CREATE TABLE radusergroup (
+CREATE TABLE IF NOT EXISTS radusergroup (
 	id INTEGER PRIMARY KEY AUTOINCREMENT,
 	username varchar(64) NOT NULL default '',
 	groupname varchar(64) NOT NULL default '',
@@ -117,18 +128,21 @@ CREATE INDEX usergroup_username ON radusergroup(username);
 --
 -- Table structure for table 'radpostauth'
 --
-CREATE TABLE radpostauth (
+CREATE TABLE IF NOT EXISTS radpostauth (
 	id INTEGER PRIMARY KEY AUTOINCREMENT,
 	username varchar(64) NOT NULL default '',
 	pass varchar(64) NOT NULL default '',
 	reply varchar(32) NOT NULL default '',
-	authdate timestamp NOT NULL
+	authdate timestamp NOT NULL,
+	class varchar(64) default NULL
 );
+CREATE INDEX radpostauth_username ON radpostauth(username);
+CREATE INDEX radpostauth_class ON radpostauth(class);
 
 --
 -- Table structure for table 'nas'
 --
-CREATE TABLE nas (
+CREATE TABLE IF NOT EXISTS nas (
 	id INTEGER PRIMARY KEY AUTOINCREMENT,
 	nasname varchar(128) NOT NULL,
 	shortname varchar(32),
